@@ -26,6 +26,8 @@
  * @author Lars Michelsen <lm@larsmichelsen.com>
  */
 class CoreModMultisite extends CoreModule {
+    private $CORE;
+
     public function __construct(GlobalCore $CORE) {
         $this->sName = 'Multisite';
         $this->CORE = $CORE;
@@ -93,6 +95,7 @@ class CoreModMultisite extends CoreModule {
             "alias" => $map['alias'],
             "url" => cfg('paths', 'htmlbase').'/index.php?mod=Map&act=view&show='.$map['name'],
             "summary_state" => $map["summary_state"],
+            "summary_output" => $map["summary_output"],
             "summary_in_downtime" => $map['summary_in_downtime'],
             "summary_problem_has_been_acknowledged" => $map['summary_problem_has_been_acknowledged'],
             "summary_stale" => $map['summary_stale'],
@@ -158,49 +161,77 @@ class CoreModMultisite extends CoreModule {
             );
             $MAP->MAPOBJ->setConfiguration($objConf);
 
+            $sources = $MAPCFG->getValue(0, 'sources') !== false ? $MAPCFG->getValue(0, 'sources') : array();
+            $is_worldmap = in_array('worldmap', $sources);
+
+            $state = null;
             if($config_error !== null) {
-                $MAP->MAPOBJ->clearMembers();
-                $MAP->MAPOBJ->setState(array(
+                $state = array(
                     ERROR,
                     l('Map Configuration Error: ').$config_error,
                     null,
                     null,
                     null,
-                ));
-                $MAP->MAPOBJ->fetchIcon();
+                );
             } elseif($error !== null) {
-                $MAP->MAPOBJ->clearMembers();
-                $MAP->MAPOBJ->setState(array(
+                $state = array(
                     ERROR,
                     l('Error: ').$error,
                     null,
                     null,
                     null,
-                ));
-                $MAP->MAPOBJ->fetchIcon();
-            } elseif($MAP->MAPOBJ->checkMaintenance(0)) {
-                $MAP->MAPOBJ->fetchIcon();
-            } else {
-                $MAP->MAPOBJ->clearMembers();
-                $MAP->MAPOBJ->setState(array(
-                    UNKNOWN,
+                );
+            } elseif($is_worldmap) {
+                // To give the correct state aggregation for the area of the
+                // worldmap the user would see when opening the worldmap, we would
+                // need this:
+                //
+                //   1. Viewport resolution of the users browser
+                //   2. Code needed to compute the bbox (LeafletJS)
+                //
+                // The first could be provided by the Checkmk frontend code. But
+                // the later one is not available there. We also don't have code
+                // to compute it in the PHP code. So, instead of doing things that
+                // would surprise users, we just skip the state computation for
+                // worldmaps here.
+                //
+                // The NagVis internal overview page needs something similar, but
+                // there we have everything we need. See the function addMap() in
+                // share/frontend/nagvis-js/js/ViewOverview.js.
+                $state = array(
+                    PENDING,
+                    l('Worldmaps do not support state preview'),
+                    null,
+                    null,
+                    null,
+                );
+            } elseif(!$MAP->MAPOBJ->checkMaintenance(0)) {
+                $state = array(
+                    PENDING,
                     l('mapInMaintenance'),
                     null,
                     null,
                     null
-                ));
-                $MAP->MAPOBJ->fetchIcon();
+                );
+            } else {
+                $MAP->MAPOBJ->queueState(GET_STATE, GET_SINGLE_MEMBER_STATES);
             }
 
-            $MAP->MAPOBJ->queueState(GET_STATE, GET_SINGLE_MEMBER_STATES);
-            $aObjs[] = $MAP->MAPOBJ;
+            $aObjs[] = array($MAP->MAPOBJ, $state);
         }
 
         $_BACKEND->execute();
 
         $aMaps = Array();
-        foreach($aObjs AS $MAP) {
-            $MAP->applyState();
+        foreach($aObjs AS list($MAP, $state)) {
+            if ($state !== null) {
+                $MAP->clearMembers();
+                $MAP->setState($state);
+                $MAP->setSummary($state);
+            } else {
+                $MAP->applyState();
+            }
+
             $MAP->fetchIcon();
 
             $aMaps[] = $MAP->getObjectInformation();
