@@ -44,6 +44,7 @@ class GlobalBackendmklivestatus implements GlobalBackendInterface {
     private $socketPath = '';
     private $socketAddress = '';
     private $socketPort = 0;
+    private $socketSpec = '';
 
     // These are the backend local configuration options
     private static $validConfig = Array(
@@ -123,7 +124,6 @@ class GlobalBackendmklivestatus implements GlobalBackendInterface {
      *
      * Parses and sets the socket options
      *
-     * @return  String    Parses the socket
      * @author  Lars Michelsen <lm@larsmichelsen.com>
      */
     private function parseSocket($socket) {
@@ -193,7 +193,7 @@ class GlobalBackendmklivestatus implements GlobalBackendInterface {
         // errors later with an own error message
         // FIXME: Maybe use pfsockopen in the future to use persistent connections
         if($this->socketType === 'unix') {
-            $this->SOCKET = fsockopen('unix://'.$this->socketPath, NULL, $errno, $errstr, (float) cfg('backend_'.$this->backendId, 'timeout'));
+            $this->SOCKET = fsockopen('unix://'.$this->socketPath, -1, $errno, $errstr, (float) cfg('backend_'.$this->backendId, 'timeout'));
 
         } elseif($this->socketType === 'tcp-tls') {
             if (cfg('backend_'.$this->backendId, 'verify_tls_peer') == true) {
@@ -367,7 +367,7 @@ class GlobalBackendmklivestatus implements GlobalBackendInterface {
         //fclose($fh);
 
         // Decode the json response
-        $obj = json_decode(utf8_encode($read));
+        $obj = json_decode(iso8859_1_to_utf8($read));
 
         // TEST: Disable KeepAlive:
         //fclose($this->SOCKET);
