@@ -32,9 +32,30 @@ class NagVisStatefulObject extends NagVisObject {
     protected $backend_id;
     protected $problem_msg = null;
 
-    protected $label_show;
+    protected $iconset;
+    protected $icon_size;
     protected $recognize_services;
+    protected $exclude_member_states;
+    protected $exclude_members;
+    protected $line_weather_colors;
+    protected $gadget_url;
+    protected $gadget_type;
+    protected $gadget_scale;
+    protected $gadget_opts;
     protected $only_hard_states;
+    protected $hover_childs_show;
+    protected $hover_childs_sort;
+    protected $hover_childs_order;
+    protected $hover_childs_limit;
+    protected $label_show;
+    protected $label_text;
+    protected $label_x;
+    protected $label_y;
+    protected $label_width;
+    protected $label_background;
+    protected $label_border;
+    protected $label_style;
+    protected $label_maxlen;
 
     protected $line_type;
 
@@ -47,6 +68,7 @@ class NagVisStatefulObject extends NagVisObject {
     protected static $dateFormat       = null;
 
     protected $state = null;
+    protected $members;
 
     public $sum = array(null, null, null, null, null);
     protected $aStateCounts = null;
@@ -76,6 +98,16 @@ class NagVisStatefulObject extends NagVisObject {
         }
     }
 
+    // Returns the display_name of an object, if available, otherwise
+    // the alias of an object, if available, otherwise the name
+    public function getDisplayName() {
+        if (isset($this->state[DISPLAY_NAME]) && $this->state[DISPLAY_NAME] != '')
+            return $this->state[DISPLAY_NAME];
+        if (isset($this->state[ALIAS]))
+            return $this->state[ALIAS];
+        parent::getDisplayName();
+    }
+
     /**
      * Adds new members to the object. It works incremental!
      */
@@ -212,12 +244,16 @@ class NagVisStatefulObject extends NagVisObject {
     }
 
     /**
-     * PUBLIC setSummaryState()
+     * PUBLIC setSummary()
      *
+     * Set the summary object
+     */
+    public function setSummary($s) {
+        $this->sum = $s;
+    }
+
+    /**
      * Set the summary state of the object
-     *
-     * @return	String		Summary state
-     * @author	Lars Michelsen <lm@larsmichelsen.com>
      */
     public function setSummaryState($s) {
         $this->sum[STATE] = $s;
@@ -276,7 +312,7 @@ class NagVisStatefulObject extends NagVisObject {
             if(self::$dateFormat == '') {
                 self::$dateFormat = cfg('global','dateformat');
             }
-            return date(self::$dateFormat, $this->state[$attr]);
+            return date(self::$dateFormat, intval($this->state[$attr]));
         } else {
             return 'N/A';
         }
@@ -553,7 +589,7 @@ class NagVisStatefulObject extends NagVisObject {
     # End public methods
     # #########################################################################
 
-    private static function sortStateCountsByState($a1, $a2) {
+    public static function sortStateCountsByState($a1, $a2) {
         if($a1['weight'] == $a2['weight']) {
             return 0;
         } elseif($a1['weight'] < $a2['weight']) {
@@ -588,6 +624,8 @@ class NagVisStatefulObject extends NagVisObject {
      * @author Lars Michelsen <lm@larsmichelsen.com>
      */
     protected function escapeStringForJson($s) {
+        if (is_null($s))
+            return '';
         return strtr($s, Array("\r" => '<br />',
                                "\n" => '<br />',
                                '"'  => '&quot;',
@@ -597,15 +635,11 @@ class NagVisStatefulObject extends NagVisObject {
 
 
     /**
-     * PROTECTED fetchObjectAsChild()
-     *
      * Is called when an object should only be displayed as child
      * e.g. in hover menus. There are much less macros needed for this.
-     *
-     * @author	Lars Michelsen <lm@larsmichelsen.com>
      */
     protected function fetchObjectAsChild() {
-        $aChild = Array(
+        return Array(
             'type'                => $this->getType(),
             'name'                => $this->getName(),
             'display_name'        => $this->escapeStringForJson($this->getDisplayName()),
@@ -615,12 +649,6 @@ class NagVisStatefulObject extends NagVisObject {
             'summary_stale'       => $this->isStale(true),
             'summary_output'      => $this->escapeStringForJson($this->sum[OUTPUT])
         );
-
-        if($this->type == 'service') {
-            $aChild['service_description'] = $this->getServiceDescription();
-        }
-
-        return $aChild;
     }
 
     /**
@@ -766,7 +794,7 @@ class NagVisStatefulObject extends NagVisObject {
         // Loop all object to gather the worst state and set it as summary
         // state of the current object
         foreach($objects AS $OBJ) {
-            if ($this->getType()=='map' && $OBJ->getType()=='map') {
+            if ($this->getType()=='map' && $OBJ->getType()=='map' && $this instanceof NagVisMapObj) {
                 if ($this->MAPCFG->getValue(0, 'ignore_linked_maps_summary_state') != 0)
                     continue;
             }
@@ -797,5 +825,113 @@ class NagVisStatefulObject extends NagVisObject {
             }
         }
     }
+
+    public function getObjectInformation($bFetchChilds = true) {
+        // When the childs don't need to be fetched this object is a child
+        // itselfs. So much less information are needed. Progress them here
+        // If someone wants more information in hover menu children, this is
+        // the place to change.
+        if (!$bFetchChilds)
+            return $this->fetchObjectAsChild();
+
+        $arr = parent::getObjectInformation($bFetchChilds);
+
+        if ($this->type == 'host' || $this->type == 'service') {
+            $obj_attrs = array(
+                'alias'         => ALIAS,
+                'display_name'  => DISPLAY_NAME,
+                'address'       => ADDRESS,
+                'notes'         => NOTES,
+                'check_command' => CHECK_COMMAND,
+            );
+            foreach ($obj_attrs AS $attr => $state_key) {
+                if (isset($this->state[$state_key]) && $this->state[$state_key] != '')
+                    $arr[$attr] = $this->state[$state_key];
+                else
+                    $arr[$attr] = '';
+            }
+        } elseif ($this->type == 'map'
+                  || $this->type == 'servicegroup'
+                  || $this->type == 'hostgroup'
+                  || $this->type == 'aggregation') {
+            if (isset($this->state[ALIAS]))
+                $arr['alias'] = $this->state[ALIAS];
+            else
+                $arr['alias'] = '';
+        }
+
+        // Add the custom htmlcgi path for the object
+        $i = 0;
+        foreach($this->backend_id as $backend_id) {
+            if($i == 0) {
+                $arr['htmlcgi']  = cfg('backend_'.$backend_id, 'htmlcgi');
+                $arr['custom_1'] = cfg('backend_'.$backend_id, 'custom_1');
+                $arr['custom_2'] = cfg('backend_'.$backend_id, 'custom_2');
+                $arr['custom_3'] = cfg('backend_'.$backend_id, 'custom_3');
+            } else {
+                $arr['htmlcgi_'.$i]  = cfg('backend_'.$backend_id, 'htmlcgi');
+                $arr['custom_1_'.$i] = cfg('backend_'.$backend_id, 'custom_1');
+                $arr['custom_2_'.$i] = cfg('backend_'.$backend_id, 'custom_2');
+                $arr['custom_3_'.$i] = cfg('backend_'.$backend_id, 'custom_3');
+            }
+            $i++;
+        }
+
+        // Little hack: Overwrite the options with correct state information
+        $arr = array_merge($arr, $this->getObjectStateInformations(false));
+
+        $num_members = $this->getNumMembers();
+        if($num_members !== null)
+            $arr['num_members'] = $num_members;
+
+        // If there are some members fetch the information for them
+        if(isset($arr['num_members']) && $arr['num_members'] > 0) {
+            $members = Array();
+            foreach($this->getSortedObjectMembers() AS $OBJ) {
+                $members[] = $OBJ->fetchObjectAsChild();
+            }
+            $arr['members'] = $members;
+        }
+
+        return $arr;
+    }
+
+    /**
+     * Gets an array of member objects
+     */
+    public function getSortedObjectMembers() {
+        $arr = Array();
+
+        $aTmpMembers = $this->getStateRelevantMembers();
+
+        // Set the sort order
+        self::$sSortOrder = $this->hover_childs_order;
+
+        // Sort the array of child objects by the sort option
+        switch($this->hover_childs_sort) {
+            case 's':
+                // Order by State
+                usort($aTmpMembers, Array("NagVisObject", "sortObjectsByState"));
+            break;
+            case 'k':
+                // Keep original order (as provided by backend)
+            break;
+            case 'a':
+            default:
+                // Order alhpabetical
+                usort($aTmpMembers, Array("NagVisObject", "sortObjectsAlphabetical"));
+            break;
+        }
+
+        // Count only once, not in loop header
+        $iNumObjects = count($aTmpMembers);
+
+        // Loop all child object until all looped or the child limit is reached
+        for($i = 0; $this->belowHoverChildsLimit($i) && $i < $iNumObjects; $i++) {
+            $arr[] = $aTmpMembers[$i];
+        }
+
+        return $arr;
+    }
 }
 ?>
