@@ -326,7 +326,7 @@ function select($name, $options, $default = '', $onchange = '', $style = '', $si
         $select = '';
         if($value == $default)
             $select = ' selected';
-        $ret .= '<option value="'.$value.'"'.$select.'>'.$display.'</option>'.N;
+        $ret .= '<option value="'.htmlspecialchars($value).'"'.$select.'>'.htmlspecialchars($display).'</option>'.N;
     }
     $ret .= '</select>'.N;
     echo $ret;
